==> gglgbtq_0.1.0.tar.gz: gglgbtq/R/zzz_data.R <==
pride_data <- list(
  rainbow = list(
    colors = c("#E40303", "#FF8C00", "#FFED00", "#008026", "#24408E", "#732982"),
    theme = theme_lgbtq_white
  ),
  philadelphia = list(
    colors = c("#000000", "#784F17", "#D12229", "#F68A1E", "#FDE01A", "#007940", "#24408E", "#732982"),
    theme = theme_lgbtq_white
  ),
  progress = list(
    colors = c("#D12229", "#F68A1E", "#FDE01A", "#007940", "#24408E", "#732982",
               "#FFFFFF", "#FFAFC8", "#74D7EE", "#784F17", "#000000")
  ),
  bisexual = list(
    colors = c("#D00070", "#8C4799", "#0032A0"),
    theme = theme_bisexual
  ),
  asexual = list(
    colors = c("#000000", "#A4A4A4", "#FFFFFF", "#810081")
  ),
  transgender = list(
    colors = c("#55CDFC", "#F7A8B8", "#FFFFFF")
  ),
  pansexual = list(
    colors = c("#FF1B8D", "#FFDA00", "#1BB3FF"),
    theme = theme_lgbtq_white
  ),
  nonbinary = list(
    colors = c("#FFF430", "#FFFFFF", "#9C59D1", "#000000")
  ),
  lesbian = list(
    colors = c("#D62900", "#FF9B55", "#FFFFFF", "#D461A6", "#A50062")
  ),
  gay_man = list(
    colors = c("#078D70", "#98E8C1", "#FFFFFF", "#7BADE2", "#3D1A78")
  ),
  intersex = list(
    colors = c("#FFD800", "#7902AA"),
    theme = theme_lgbtq_white
  ),
  aromantic = list(
    colors = c("#3DA542", "#A7D379", "#FFFFFF", "#A4A4A4", "#000000")
  ),
  genderfluid = list(
    colors = c("#FF76A4", "#FFFFFF", "#C011D7", "#000000", "#2F3CBE")
  ),
  genderqueer = list(
    colors = c("#B57EDC", "#FFFFFF", "#4A8123")
  ),
  lesbian_7 = list(
    colors = c("#A60061", "#B95594", "#D162A8", "#FFFFFF", "#E5ADD1", "#C64D53", "#8C1801")
  ),
  gay_man_7 = list(
    colors = c("#078D70", "#26CEAA", "#98E8C1", "#FFFFFF", "#7BADE2", "#5049CC", "#3D1A78")
  )
)

==> gglgbtq_0.1.1.tar.gz: gglgbtq/R/zzz_data.R <==
pride_data <- list(
  rainbow = list(
    colors = c("#E40303", "#FF8C00", "#FFED00", "#008026", "#24408E", "#732982"),
    theme = theme_lgbtq_white
  ),
  philadelphia = list(
    colors = c("#000000", "#784F17", "#D12229", "#F68A1E", "#FDE01A", "#007940", "#24408E", "#732982"),
    theme = theme_lgbtq_white
  ),
  progress = list(
    colors = c("#D12229", "#F68A1E", "#FDE01A", "#007940", "#24408E", "#732982",
               "#FFFFFF", "#FFAFC8", "#74D7EE", "#784F17", "#000000")
  ),
  bisexual = list(
    colors = c("#D00070", "#8C4799", "#0032A0"),
    theme = theme_ggplot2
  ),
  asexual = list(
    colors = c("#000000", "#A4A4A4", "#FFFFFF", "#810081")
  ),
  transgender = list(
    colors = c("#55CDFC", "#F7A8B8", "#FFFFFF")
  ),
  pansexual = list(
    colors = c("#FF1B8D", "#FFDA00", "#1BB3FF"),
    theme = theme_lgbtq_white
  ),
  nonbinary = list(
    colors = c("#FFF430", "#FFFFFF", "#9C59D1", "#000000")
  ),
  lesbian = list(
    colors = c("#D62900", "#FF9B55", "#FFFFFF", "#D461A6", "#A50062")
  ),
  gay = list(
    colors = c("#078D70", "#98E8C1", "#FFFFFF", "#7BADE2", "#3D1A78")
  ),
  intersex = list(
    colors = c("#FFD800", "#7902AA"),
    theme = theme_lgbtq_white
  ),
  aromantic = list(
    colors = c("#3DA542", "#A7D379", "#FFFFFF", "#A4A4A4", "#000000")
  ),
  genderfluid = list(
    colors = c("#FF76A4", "#FFFFFF", "#C011D7", "#000000", "#2F3CBE")
  ),
  genderqueer = list(
    colors = c("#B57EDC", "#FFFFFF", "#4A8123")
  ),
  lesbian_7 = list(
    colors = c("#A60061", "#B95594", "#D162A8", "#FFFFFF", "#E5ADD1", "#C64D53", "#8C1801")
  ),
  gay_7 = list(
    colors = c("#078D70", "#26CEAA", "#98E8C1", "#FFFFFF", "#7BADE2", "#5049CC", "#3D1A78")
  ),
  agender = list(
    colors = c("#000000", "#BCC4C7", "#FFFFFF", "#B7F684"),
    theme = theme_agender
  ),
  demiboy = list(
    colors = c("#7F7F7F", "#C4C4C4", "#9DD7EA", "#FFFFFF"),
    theme = theme_demiboy
  ),
  demigirl = list(
    colors = c("#7F7F7F", "#C4C4C4", "#FDADC8", "#FFFFFF"),
    theme = theme_demigirl
  ),
  bigender = list(
    colors = c("#C479A2", "#EDA5CD", "#D6C7E8", "#FFFFFF", "#9AC7E8", "#6D82D1"),
    theme = theme_ggplot2
  ),
  alloace = list(
    colors = c("#D50100", "#F85858", "#FFFFFF", "#81007F")
  ),
  aroallo = list(
    colors = c("#3DA542", "#A8D379", "#FFFFFF", "#FBE34B", "#E8BB00")
  )
)
